@@ -61,31 +61,28 @@ test_that("find_permuted_perf_metric works", {
 })
 
 feat_imp <- structure(list(perf_metric = c(
-  0.638605263157895, 0.649368421052632,
-  0.631842105263158, 0.628052631578947, 0.597105263157895, 0.635210526315789,
-  0.640236842105263, 0.603184210526316, 0.644394736842105, 0.638421052631579
+  0.629157894736842, 0.605473684210526,
+  0.638789473684211, 0.636763157894737, 0.629447368421053, 0.637868421052632,
+  0.642552631578947, 0.592157894736842, 0.639684210526316, 0.637526315789474
 ), perf_metric_diff = c(
-  0.00876315789473692, -0.00200000000000022,
-  0.0155263157894737, 0.0193157894736846, 0.0502631578947367, 0.0121578947368423,
-  0.00713157894736849, 0.0441842105263159, 0.00297368421052646,
-  0.00894736842105293
-), names = structure(c(
-  9L, 5L, 10L, 1L, 8L,
-  4L, 3L, 2L, 7L, 6L
-), .Label = c(
-  "Otu00001", "Otu00002", "Otu00003",
-  "Otu00004", "Otu00005", "Otu00006", "Otu00007", "Otu00008", "Otu00009",
-  "Otu00010"
+  0.0182105263157896, 0.0418947368421053,
+  0.00857894736842102, 0.0106052631578948, 0.0179210526315789,
+  0.00950000000000006, 0.00481578947368433, 0.0552105263157895,
+  0.00768421052631585, 0.00984210526315799
+), names = structure(1:10, .Label = c(
+  "Otu00001",
+  "Otu00002", "Otu00003", "Otu00004", "Otu00005", "Otu00006", "Otu00007",
+  "Otu00008", "Otu00009", "Otu00010"
 ), class = "factor"), method = c(
-  "glmnet", "glmnet",
+  "glmnet",
   "glmnet", "glmnet", "glmnet", "glmnet", "glmnet", "glmnet", "glmnet",
-  "glmnet"
+  "glmnet", "glmnet"
 ), perf_metric_name = c(
-  "AUC", "AUC", "AUC", "AUC", "AUC",
-  "AUC", "AUC", "AUC", "AUC", "AUC"
+  "AUC", "AUC", "AUC",
+  "AUC", "AUC", "AUC", "AUC", "AUC", "AUC", "AUC"
 ), seed = c(
-  2019, 2019, 2019,
-  2019, 2019, 2019, 2019, 2019, 2019, 2019
+  2019,
+  2019, 2019, 2019, 2019, 2019, 2019, 2019, 2019, 2019
 )), row.names = c(
   NA,
   -10L
@@ -156,35 +153,28 @@ test_that("custom grouped features works", {
       seed = 2019,
       groups = groups
     ),
-    data.frame(
-      perf_metric = c(
-        0.638605263157895, 0.631263157894737,
-        0.630815789473684, 0.59628947368421, 0.637368421052632, 0.6425,
-        0.636, 0.584657894736842
-      ),
-      perf_metric_diff = c(
-        0.00876315789473692,
-        0.0161052631578947, 0.0165526315789474, 0.0510789473684211, 0.01,
-        0.00486842105263163, 0.0113684210526316, 0.0627105263157894
-      ),
-      names = structure(c(7L, 8L, 1L, 6L, 3L, 5L, 4L, 2L),
-        .Label = c(
-          "Otu00001", "Otu00003|Otu00005|Otu00002", "Otu00004", "Otu00006", "Otu00007",
-          "Otu00008", "Otu00009", "Otu00010"
-        ), class = "factor"
-      ),
-      method = c(
-        "glmnet", "glmnet", "glmnet", "glmnet",
-        "glmnet", "glmnet", "glmnet", "glmnet"
-      ),
-      perf_metric_name = c(
-        "AUC", "AUC", "AUC", "AUC",
-        "AUC", "AUC", "AUC", "AUC"
-      ),
-      seed = c(
-        2019, 2019, 2019, 2019,
-        2019, 2019, 2019, 2019
-      )
-    )
+    structure(list(perf_metric = c(
+      0.629157894736842, 0.596921052631579,
+      0.633605263157895, 0.639105263157895, 0.642421052631579, 0.596842105263158,
+      0.640289473684211, 0.629868421052632
+    ), perf_metric_diff = c(
+      0.0182105263157896,
+      0.0504473684210527, 0.0137631578947369, 0.00826315789473686,
+      0.00494736842105259, 0.0505263157894738, 0.00707894736842096,
+      0.0175000000000001
+    ), names = structure(1:8, .Label = c(
+      "Otu00001",
+      "Otu00002|Otu00003|Otu00005", "Otu00004", "Otu00006", "Otu00007",
+      "Otu00008", "Otu00009", "Otu00010"
+    ), class = "factor"), method = c(
+      "glmnet",
+      "glmnet", "glmnet", "glmnet", "glmnet", "glmnet", "glmnet", "glmnet"
+    ), perf_metric_name = c(
+      "AUC", "AUC", "AUC", "AUC", "AUC", "AUC",
+      "AUC", "AUC"
+    ), seed = c(
+      2019, 2019, 2019, 2019, 2019, 2019, 2019,
+      2019
+    )), row.names = c(NA, -8L), class = "data.frame")
   )
 })
